@@ -81,7 +81,7 @@ class Base(metaclass=BaseMetaclass):
     def get_table_dict(self):
         table_dict = {}
         for key, value in vars(self).items():
-            if key.startswith("_") or isinstance(value, property) or callable(value):
+            if key.startswith("_") or isinstance(value, (property, classmethod, staticmethod)) or callable(value):
                 continue
             table_dict[key] = value
         return table_dict
@@ -91,11 +91,14 @@ class Base(metaclass=BaseMetaclass):
         for key, value in vars(type(self)).items():
             if isinstance(value, property):
                 sub_object = getattr(self, key)
-                if isinstance(sub_object, list):
-                    sub_dict = [obj.get_complete_dict() for obj in sub_object]
-                    complete_dict[key] = sub_dict
-                else:
-                    complete_dict[key] = sub_object.get_complete_dict()
+                try:
+                    if isinstance(sub_object, list):
+                        sub_dict = [obj.get_complete_dict() for obj in sub_object]
+                        complete_dict[key] = sub_dict
+                    else:
+                        complete_dict[key] = sub_object.get_complete_dict()
+                except AttributeError:
+                    continue
         return complete_dict
 
     def update(self, arg_dict={}, **kwargs):
